==> lxqt-l10n-0.11.0-1-src.tar.xz: lxqt-l10n-0.11.0/lxqt-session/lxqt-config-session/lxqt-config-session_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../../../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>حرّر</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>الاسم:</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>ابحث...</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>الأمر:</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>انتظر صينيّة النّظام</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.cpp" line="59"/>
        <source>Select Application</source>
        <translation>اختر تطبيقًا</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../../../autostartmodel.cpp" line="191"/>
        <source>Global Autostart</source>
        <translation>البدء الآليّ العموميّ</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="193"/>
        <source>LXQt Autostart</source>
        <translation>البدء الآليّ لِلكسكيوت</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="211"/>
        <source>Location: %1</source>
        <translation>المكان: %1</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="213"/>
        <source>Overrides: %1</source>
        <translation>يتجاهل: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../../../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>احذف</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>أضف</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>حرّر</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>بدء التّطبيقات الآليّ</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.cpp" line="141"/>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.cpp" line="141"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>الملفّ &apos;%1&apos; موجود بالفعل!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../../../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>الإعدادات الأساسيّة</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>مدير النّوافذ</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>ابحث...</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>وحدات لكسكيوت</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>ابدأ</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>أوقف</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation>ترك الجلسة</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation>اسأل لتأكيد ترك الجلسة</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="137"/>
        <source>Select a window manager</source>
        <translation>اختر مدير النّوافذ</translation>
    </message>
</context>
<context>
    <name>DefaultApps</name>
    <message>
        <location filename="../../../defaultappspage.cpp" line="72"/>
        <source>Select a terminal emulator</source>
        <translation>اختر محاكي الطّرفيّة</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.cpp" line="77"/>
        <source>Select a web browser</source>
        <translation>اختر متصفّح الوبّ</translation>
    </message>
</context>
<context>
    <name>DefaultAppsPage</name>
    <message>
        <location filename="../../../defaultappspage.ui" line="23"/>
        <source>Default Applications</source>
        <translation>التّطبيقات الافتراضيّة</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="32"/>
        <source>Terminal Emulation:</source>
        <translation>محاكي الطّرفيّة:</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="52"/>
        <location filename="../../../defaultappspage.ui" line="79"/>
        <source>Search...</source>
        <translation>ابحث...</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="59"/>
        <source>Web Browser:</source>
        <translation>متصّفح الوبّ:</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../../../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>أضف</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>احذف</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>متغيّرات البيئة (متقدّم)</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>اسم المتغيّر</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>القيمة</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../../../modulemodel.cpp" line="86"/>
        <source>Running</source>
        <translation>تعمل</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>إعدادات لكسكيوت للجلسة</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>الإعدادات الأساسيّة</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="53"/>
        <source>Default Applications</source>
        <translation>التّطبيقات الافتراضيّة</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="56"/>
        <source>User Directories</source>
        <translation>أدلّة المستخدم</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="62"/>
        <source>Autostart</source>
        <translation>البدء الآليّ</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="68"/>
        <source>Environment (Advanced)</source>
        <translation>البيئة (متقدّم)</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="94"/>
        <source>Session Restart Required</source>
        <translation>إعادة تشغيل الجلسة مطلوبة</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="95"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>بعض من هذه الإعدادات لن تُطبّق حتّى الولوج التّالي.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../../../userlocationspage.cpp" line="110"/>
        <source>Locations for Personal Files</source>
        <translation>أماكن الملفّات الشّخصيّة</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="179"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>إعدادات لكسكيوت للجلسة - أدلّة المستخدم</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="180"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation>حدث خطأ أثناء تطبيق الإعدادات للمكان %1</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="196"/>
        <source>Choose Location</source>
        <translation>اختر مكانًا</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../../../userlocationspage.cpp" line="60"/>
        <source>Desktop</source>
        <translation>سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="61"/>
        <source>Downloads</source>
        <translation>التّنزيلات</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="62"/>
        <source>Templates</source>
        <translation>القوالب</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="63"/>
        <source>Public Share</source>
        <translation>المشاركة مع العموم</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="64"/>
        <source>Documents</source>
        <translation>المستندات</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="65"/>
        <source>Music</source>
        <translation>الموسيقى</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="66"/>
        <source>Pictures</source>
        <translation>الصّور</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="67"/>
        <source>Videos</source>
        <translation>الفيديوهات</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="70"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>فيه كلّ الملفّات التي تراها على سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="71"/>
        <source>Default folder to save your downloaded files</source>
        <translation>المجلّد الافتراضيّ حيث تُحفظ ملفّاتك المنزّلة فيه</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="72"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>المجلّد الافتراضيّ حيث تُحمّل القوالب منه وتُحفظ إليه</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="73"/>
        <source>Default folder to publicly share your files</source>
        <translation>المجلّد الافتراضيّ حيث تنشر فيها ملفّاتك للعموم</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="74"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>المجلّد الافتراضيّ حيث تُحمّل المستندات منه وتُحفظ فيه</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="75"/>
        <source>Default foldet to load or save music from or to</source>
        <translation>المجلّد الافتراضيّ حيث تُحمّل الموسيقى منه وتُحفظ فيه</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="76"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>المجلّد الافتراضيّ حيث تُحمّل الصّور منه وتُحفظ فيه</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>المجلّد الافتراضيّ حيث تُحمّل الفيديوات منه وتُحفظ فيه</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.12.0-1-src.tar.xz: lxqt-l10n-0.12.0/lxqt-session/lxqt-config-session/lxqt-config-session_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ar">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../../../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>حرّر</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>الاسم:</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>ابحث...</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>الأمر:</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>انتظر صينيّة النّظام</translation>
    </message>
    <message>
        <location filename="../../../autostartedit.cpp" line="59"/>
        <source>Select Application</source>
        <translation>اختر تطبيقًا</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../../../autostartmodel.cpp" line="191"/>
        <source>Global Autostart</source>
        <translation>البدء الآليّ العموميّ</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="193"/>
        <source>LXQt Autostart</source>
        <translation>البدء الآليّ لِلكسكيوت</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="211"/>
        <source>Location: %1</source>
        <translation>المكان: %1</translation>
    </message>
    <message>
        <location filename="../../../autostartmodel.cpp" line="213"/>
        <source>Overrides: %1</source>
        <translation>يتجاهل: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../../../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>احذف</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>أضف</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>حرّر</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>بدء التّطبيقات الآليّ</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.cpp" line="141"/>
        <source>Error</source>
        <translation>خطأ</translation>
    </message>
    <message>
        <location filename="../../../autostartpage.cpp" line="141"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>الملفّ &apos;%1&apos; موجود بالفعل!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../../../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>الإعدادات الأساسيّة</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>مدير النّوافذ</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>ابحث...</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>وحدات لكسكيوت</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>ابدأ</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>أوقف</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="111"/>
        <source>Leave Session</source>
        <translation>ترك الجلسة</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="117"/>
        <source>Ask for confirmation to leave session</source>
        <translation>اسأل لتأكيد ترك الجلسة</translation>
    </message>
    <message>
        <location filename="../../../basicsettings.ui" line="124"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../../basicsettings.cpp" line="146"/>
        <source>Select a window manager</source>
        <translation>اختر مدير النّوافذ</translation>
    </message>
</context>
<context>
    <name>DefaultApps</name>
    <message>
        <location filename="../../../defaultappspage.cpp" line="72"/>
        <source>Select a terminal emulator</source>
        <translation>اختر محاكي الطّرفيّة</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.cpp" line="77"/>
        <source>Select a web browser</source>
        <translation>اختر متصفّح الوبّ</translation>
    </message>
</context>
<context>
    <name>DefaultAppsPage</name>
    <message>
        <location filename="../../../defaultappspage.ui" line="23"/>
        <source>Default Applications</source>
        <translation>التّطبيقات الافتراضيّة</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="32"/>
        <source>Terminal Emulation:</source>
        <translation>محاكي الطّرفيّة:</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="52"/>
        <location filename="../../../defaultappspage.ui" line="79"/>
        <source>Search...</source>
        <translation>ابحث...</translation>
    </message>
    <message>
        <location filename="../../../defaultappspage.ui" line="59"/>
        <source>Web Browser:</source>
        <translation>متصّفح الوبّ:</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../../../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>أضف</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>احذف</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>متغيّرات البيئة (متقدّم)</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>اسم المتغيّر</translation>
    </message>
    <message>
        <location filename="../../../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>القيمة</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../../../modulemodel.cpp" line="86"/>
        <source>Running</source>
        <translation>تعمل</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>إعدادات لكسكيوت للجلسة</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>الإعدادات الأساسيّة</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="53"/>
        <source>Default Applications</source>
        <translation>التّطبيقات الافتراضيّة</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="56"/>
        <source>User Directories</source>
        <translation>أدلّة المستخدم</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="62"/>
        <source>Autostart</source>
        <translation>البدء الآليّ</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="68"/>
        <source>Environment (Advanced)</source>
        <translation>البيئة (متقدّم)</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="94"/>
        <source>Session Restart Required</source>
        <translation>إعادة تشغيل الجلسة مطلوبة</translation>
    </message>
    <message>
        <location filename="../../../sessionconfigwindow.cpp" line="95"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>بعض من هذه الإعدادات لن تُطبّق حتّى الولوج التّالي.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../../../userlocationspage.cpp" line="110"/>
        <source>Locations for Personal Files</source>
        <translation>أماكن الملفّات الشّخصيّة</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="179"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>إعدادات لكسكيوت للجلسة - أدلّة المستخدم</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="180"/>
        <source>An error ocurred while applying the settings for the %1 location</source>
        <translation>حدث خطأ أثناء تطبيق الإعدادات للمكان %1</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="196"/>
        <source>Choose Location</source>
        <translation>اختر مكانًا</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../../../userlocationspage.cpp" line="60"/>
        <source>Desktop</source>
        <translation>سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="61"/>
        <source>Downloads</source>
        <translation>التّنزيلات</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="62"/>
        <source>Templates</source>
        <translation>القوالب</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="63"/>
        <source>Public Share</source>
        <translation>المشاركة مع العموم</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="64"/>
        <source>Documents</source>
        <translation>المستندات</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="65"/>
        <source>Music</source>
        <translation>الموسيقى</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="66"/>
        <source>Pictures</source>
        <translation>الصّور</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="67"/>
        <source>Videos</source>
        <translation>الفيديوهات</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="70"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>فيه كلّ الملفّات التي تراها على سطح المكتب</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="71"/>
        <source>Default folder to save your downloaded files</source>
        <translation>المجلّد الافتراضيّ حيث تُحفظ ملفّاتك المنزّلة فيه</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="72"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>المجلّد الافتراضيّ حيث تُحمّل القوالب منه وتُحفظ إليه</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="73"/>
        <source>Default folder to publicly share your files</source>
        <translation>المجلّد الافتراضيّ حيث تنشر فيها ملفّاتك للعموم</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="74"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>المجلّد الافتراضيّ حيث تُحمّل المستندات منه وتُحفظ فيه</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="75"/>
        <source>Default foldet to load or save music from or to</source>
        <translation>المجلّد الافتراضيّ حيث تُحمّل الموسيقى منه وتُحفظ فيه</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="76"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>المجلّد الافتراضيّ حيث تُحمّل الصّور منه وتُحفظ فيه</translation>
    </message>
    <message>
        <location filename="../../../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>المجلّد الافتراضيّ حيث تُحمّل الفيديوات منه وتُحفظ فيه</translation>
    </message>
</context>
</TS>
